@@ -18,11 +18,11 @@ class Common(models.Model):
     terrifnsul = models.PositiveIntegerField(blank=True, null=True)
 
     okato = models.BigIntegerField(blank=True, null=True)
-    oktmo = models.IntegerField(blank=True, null=True)
+    oktmo = models.BigIntegerField(blank=True, null=True)
 
     postalcode = models.PositiveIntegerField(blank=True, null=True)
 
     updatedate = models.DateField()
     startdate = models.DateField()
     enddate = models.DateField()
-    normdoc = UUIDField(blank=True, null=True, auto=False)
\ No newline at end of file
+    normdoc = UUIDField(blank=True, null=True, auto=False)
